@@ -1,5 +1,5 @@
 /**********************************************************************
-  iso8859_15.c -  Oniguruma (regular expression library)
+  iso8859_16.c -  Oniguruma (regular expression library)
 **********************************************************************/
 /*-
  * Copyright (c) 2002-2007  K.Kosako  <sndgk393 AT ybb DOT ne DOT jp>
@@ -30,11 +30,11 @@
 #include "regenc.h"
 #include "iso_8859.h"
 
-#define ENC_ISO_8859_15_TO_LOWER_CASE(c) EncISO_8859_15_ToLowerCaseTable[c]
-#define ENC_IS_ISO_8859_15_CTYPE(code,ctype) \
-  ((EncISO_8859_15_CtypeTable[code] & CTYPE_TO_BIT(ctype)) != 0)
+#define ENC_ISO_8859_16_TO_LOWER_CASE(c) EncISO_8859_16_ToLowerCaseTable[c]
+#define ENC_IS_ISO_8859_16_CTYPE(code,ctype) \
+  ((EncISO_8859_16_CtypeTable[code] & CTYPE_TO_BIT(ctype)) != 0)
 
-static const UChar EncISO_8859_15_ToLowerCaseTable[256] = {
+static const UChar EncISO_8859_16_ToLowerCaseTable[256] = {
   '\000', '\001', '\002', '\003', '\004', '\005', '\006', '\007',
   '\010', '\011', '\012', '\013', '\014', '\015', '\016', '\017',
   '\020', '\021', '\022', '\023', '\024', '\025', '\026', '\027',
@@ -55,13 +55,13 @@ static const UChar EncISO_8859_15_ToLowerCaseTable[256] = {
   '\210', '\211', '\212', '\213', '\214', '\215', '\216', '\217',
   '\220', '\221', '\222', '\223', '\224', '\225', '\226', '\227',
   '\230', '\231', '\232', '\233', '\234', '\235', '\236', '\237',
-  '\240', '\241', '\242', '\243', '\244', '\245', '\250', '\247',
-  '\250', '\251', '\252', '\253', '\254', '\255', '\256', '\257',
-  '\260', '\261', '\262', '\263', '\270', '\265', '\266', '\267',
+  '\240', '\242', '\242', '\263', '\245', '\245', '\250', '\247',
+  '\250', '\251', '\272', '\253', '\256', '\255', '\256', '\277',
+  '\260', '\261', '\271', '\263', '\270', '\265', '\266', '\267',
   '\270', '\271', '\272', '\273', '\275', '\275', '\377', '\277',
   '\340', '\341', '\342', '\343', '\344', '\345', '\346', '\347',
   '\350', '\351', '\352', '\353', '\354', '\355', '\356', '\357',
-  '\360', '\361', '\362', '\363', '\364', '\365', '\366', '\327',
+  '\360', '\361', '\362', '\363', '\364', '\365', '\366', '\367',
   '\370', '\371', '\372', '\373', '\374', '\375', '\376', '\337',
   '\340', '\341', '\342', '\343', '\344', '\345', '\346', '\347',
   '\350', '\351', '\352', '\353', '\354', '\355', '\356', '\357',
@@ -69,7 +69,7 @@ static const UChar EncISO_8859_15_ToLowerCaseTable[256] = {
   '\370', '\371', '\372', '\373', '\374', '\375', '\376', '\377'
 };
 
-static const unsigned short EncISO_8859_15_CtypeTable[256] = {
+static const unsigned short EncISO_8859_16_CtypeTable[256] = {
   0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008,
   0x4008, 0x420c, 0x4209, 0x4208, 0x4208, 0x4208, 0x4008, 0x4008,
   0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008,
@@ -90,24 +90,24 @@ static const unsigned short EncISO_8859_15_CtypeTable[256] = {
   0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008,
   0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008,
   0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008,
-  0x0284, 0x01a0, 0x00a0, 0x00a0, 0x00a0, 0x00a0, 0x34a2, 0x00a0,
-  0x30e2, 0x00a0, 0x30e2, 0x01a0, 0x00a0, 0x01a0, 0x00a0, 0x00a0,
-  0x00a0, 0x00a0, 0x10a0, 0x10a0, 0x34a2, 0x30e2, 0x00a0, 0x01a0,
-  0x30e2, 0x10a0, 0x30e2, 0x01a0, 0x34a2, 0x30e2, 0x34a2, 0x01a0,
+  0x0284, 0x34a2, 0x30e2, 0x34a2, 0x00a0, 0x01a0, 0x34a2, 0x00a0,
+  0x30e2, 0x00a0, 0x34a2, 0x01a0, 0x34a2, 0x01a0, 0x30e2, 0x34a2,
+  0x00a0, 0x00a0, 0x34a2, 0x30e2, 0x34a2, 0x01a0, 0x00a0, 0x01a0,
+  0x30e2, 0x30e2, 0x30e2, 0x01a0, 0x34a2, 0x30e2, 0x34a2, 0x30e2,
+  0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2,
   0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2,
   0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2,
-  0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x00a0,
   0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x30e2,
   0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2,
   0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2,
-  0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x00a0,
+  0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2,
   0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2
 };
 
 static int
 mbc_case_fold(OnigCaseFoldType flag,
-			  const UChar** pp, const UChar* end ARG_UNUSED,
-			  UChar* lower, OnigEncoding enc ARG_UNUSED)
+			  const UChar** pp, const UChar* end ARG_UNUSED, UChar* lower,
+			  OnigEncoding enc ARG_UNUSED)
 {
   const UChar* p = *pp;
 
@@ -118,15 +118,14 @@ mbc_case_fold(OnigCaseFoldType flag,
     return 2;
   }
 
-  *lower = ENC_ISO_8859_15_TO_LOWER_CASE(*p);
+  *lower = ENC_ISO_8859_16_TO_LOWER_CASE(*p);
   (*pp)++;
   return 1; /* return byte length of converted char to lower */
 }
 
 #if 0
 static int
-is_mbc_ambiguous(OnigCaseFoldType flag,
-		 const UChar** pp, const UChar* end)
+is_mbc_ambiguous(OnigCaseFoldType flag, const UChar** pp, const UChar* end)
 {
   int v;
   const UChar* p = *pp;
@@ -137,13 +136,9 @@ is_mbc_ambiguous(OnigCaseFoldType flag,
   }
 
   (*pp)++;
-  v = (EncISO_8859_15_CtypeTable[*p] & (BIT_CTYPE_UPPER | BIT_CTYPE_LOWER));
+  v = (EncISO_8859_16_CtypeTable[*p] & (BIT_CTYPE_UPPER | BIT_CTYPE_LOWER));
   if ((v | BIT_CTYPE_LOWER) != 0) {
-    /* 0xdf etc.. are lower case letter, but can't convert. */
-    if (*p == 0xaa || *p == 0xb5 || *p == 0xba)
-      return FALSE;
-    else
-      return TRUE;
+    return TRUE;
   }
 
   return (v != 0 ? TRUE : FALSE);
@@ -154,14 +149,20 @@ static int
 is_code_ctype(OnigCodePoint code, unsigned int ctype, OnigEncoding enc ARG_UNUSED)
 {
   if (code < 256)
-    return ENC_IS_ISO_8859_15_CTYPE(code, ctype);
+    return ENC_IS_ISO_8859_16_CTYPE(code, ctype);
   else
     return FALSE;
 }
 
 static const OnigPairCaseFoldCodes CaseFoldMap[] = {
+ { 0xa1, 0xa2 },
+ { 0xa3, 0xb3 },
  { 0xa6, 0xa8 },
+ { 0xaa, 0xba },
+ { 0xac, 0xae },
+ { 0xaf, 0xbf },
 
+ { 0xb2, 0xb9 },
  { 0xb4, 0xb8 },
  { 0xbc, 0xbd },
  { 0xbe, 0xff },
@@ -190,6 +191,7 @@ static const OnigPairCaseFoldCodes CaseFoldMap[] = {
  { 0xd4, 0xf4 },
  { 0xd5, 0xf5 },
  { 0xd6, 0xf6 },
+ { 0xd7, 0xf7 },
  { 0xd8, 0xf8 },
  { 0xd9, 0xf9 },
  { 0xda, 0xfa },
@@ -244,22 +246,24 @@ case_map(OnigCaseFoldType* flagP, const OnigUChar** pp,
 	code = 's';
       }
     }
-    else if (code == 0xAA || code == 0xBA || code == 0xB5)
-      ;
-    else if ((EncISO_8859_15_CtypeTable[code] & BIT_CTYPE_UPPER)
+    else if ((EncISO_8859_16_CtypeTable[code] & BIT_CTYPE_UPPER)
 	     && (flags & (ONIGENC_CASE_DOWNCASE | ONIGENC_CASE_FOLD))) {
       flags |= ONIGENC_CASE_MODIFIED;
-      code = ENC_ISO_8859_15_TO_LOWER_CASE(code);
+      code = ENC_ISO_8859_16_TO_LOWER_CASE(code);
     }
-    else if ((EncISO_8859_15_CtypeTable[code] & BIT_CTYPE_LOWER)
-	     && (flags & ONIGENC_CASE_UPCASE)) {
+    else if ((EncISO_8859_16_CtypeTable[code] & BIT_CTYPE_LOWER)
+	     && (flags&ONIGENC_CASE_UPCASE)) {
       flags |= ONIGENC_CASE_MODIFIED;
-      if (code == 0xA8)
-	code -= 2;
+      if (code == 0xA2 || code == 0xBD)
+	code--;
+      else if (code == 0xB3 || code == 0xBA || code == 0xBF)
+	code -= 0x10;
+      else if (code == 0xA8 || code == 0xAE)
+	code -= 0x02;
+      else if (code == 0xB9)
+	code -= 0x07;
       else if (code == 0xB8)
-	code -= 4;
-      else if (code == 0xBD)
-	code -= 1;
+	code -= 0x04;
       else if (code == 0xFF)
 	code -= 0x41;
       else
@@ -274,9 +278,9 @@ case_map(OnigCaseFoldType* flagP, const OnigUChar** pp,
 }
 #endif
 
-OnigEncodingDefine(iso_8859_15, ISO_8859_15) = {
+OnigEncodingDefine(iso_8859_16, ISO_8859_16) = {
   onigenc_single_byte_mbc_enc_len,
-  "ISO-8859-15",  /* name */
+  "ISO-8859-16",  /* name */
   1,             /* max enc length */
   1,             /* min enc length */
   onigenc_is_mbc_newline_0x0a,
@@ -299,4 +303,4 @@ OnigEncodingDefine(iso_8859_15, ISO_8859_15) = {
   0,
   ONIGENC_FLAG_NONE,
 };
-ENC_ALIAS("ISO8859-15", "ISO-8859-15")
+ENC_ALIAS("ISO8859-16", "ISO-8859-16")
