@@ -4,7 +4,8 @@
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
-  License version 2.1 as published by the Free Software Foundation.
+  License as published by the Free Software Foundation; either
+  version 2.1 of the License, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -134,7 +135,7 @@ grn_alloc_info_fin(void)
   CRITICAL_SECTION_FIN(grn_alloc_info_lock);
 }
 
-grn_inline static void
+static inline void
 grn_alloc_info_set_backtrace(char *buffer, size_t size)
 {
 #  ifdef HAVE_BACKTRACE
@@ -173,7 +174,7 @@ grn_alloc_info_set_backtrace(char *buffer, size_t size)
 #  endif /* HAVE_BACKTRACE */
 }
 
-grn_inline static void
+static inline void
 grn_alloc_info_add(
   void *address, size_t size, const char *file, int line, const char *func)
 {
@@ -210,7 +211,7 @@ grn_alloc_info_add(
   CRITICAL_SECTION_LEAVE(grn_alloc_info_lock);
 }
 
-grn_inline static void
+static inline void
 grn_alloc_info_change(void *old_address, void *new_address, size_t size)
 {
   grn_ctx *ctx;
@@ -269,7 +270,7 @@ grn_alloc_info_dump(grn_ctx *ctx)
   printf("total: %" GRN_FMT_SIZE ":%d\n", total, i);
 }
 
-grn_inline static void
+static inline void
 grn_alloc_info_check(grn_ctx *ctx, void *address)
 {
   grn_alloc_info *alloc_info;
