@@ -37,17 +37,17 @@ class GRN_DAT_API PredictiveCursor : public Cursor {
             UInt32 limit = MAX_UINT32,
             UInt32 flags = 0);
 
-  void close();
+  void close() override;
 
-  const Key &next();
+  const Key &next() override;
 
-  UInt32 offset() const {
+  UInt32 offset() const override {
     return offset_;
   }
-  UInt32 limit() const {
+  UInt32 limit() const override {
     return limit_;
   }
-  UInt32 flags() const {
+  UInt32 flags() const override {
     return flags_;
   }
 
