@@ -3,7 +3,8 @@
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
-  License version 2.1 as published by the Free Software Foundation.
+  License as published by the Free Software Foundation; either
+  version 2.1 of the License, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -195,7 +196,7 @@ namespace {
               continue;
             }
             auto distance_raw = distance_func(task_ctx, &input, literal);
-            if (ctx->rc != GRN_SUCCESS) {
+            if (task_ctx->rc != GRN_SUCCESS) {
               continue;
             }
             GRN_FLOAT_SET(task_ctx, &output, distance_raw);
@@ -204,7 +205,7 @@ namespace {
                               id,
                               &output,
                               GRN_OBJ_SET);
-            if (ctx->rc != GRN_SUCCESS) {
+            if (task_ctx->rc != GRN_SUCCESS) {
               continue;
             }
           }
