@@ -18,12 +18,13 @@
 */
 
 #include "grn_index_column.h"
-#include "grn_ii.h"
-#include "grn_float.h"
-#include "grn_hash.h"
 
-#include <string.h>
+#include "grn_hash.h"
+#include "grn_ii.h"
+#include "grn_progress_logger.h"
+
 #include <math.h>
+#include <string.h>
 
 static uint64_t grn_index_sparsity = 10;
 
@@ -386,13 +387,8 @@ typedef struct {
     grn_obj postings;
   } buffers;
   struct {
-    unsigned int n_records;
-    unsigned int i;
-    unsigned int interval;
-    int n_records_digits;
-    grn_log_level log_level;
-    grn_timeval start_time;
-    grn_timeval previous_time;
+    grn_obj tag;
+    grn_progress_logger logger;
   } progress;
 } grn_index_column_diff_data;
 
@@ -437,133 +433,34 @@ grn_index_column_diff_data_fin(grn_ctx *ctx, grn_index_column_diff_data *data)
   GRN_OBJ_FIN(ctx, &(data->buffers.value));
   GRN_OBJ_FIN(ctx, &(data->buffers.postings));
   grn_hash_close(ctx, data->current.token_counters);
+  GRN_OBJ_FIN(ctx, &(data->progress.tag));
 }
 
 static void
 grn_index_column_diff_init_progress(grn_ctx *ctx,
                                     grn_index_column_diff_data *data)
 {
-  data->progress.n_records = grn_table_size(ctx, data->source_table);
-  data->progress.i = 0;
-  data->progress.interval = 10000;
-  data->progress.log_level =
+  GRN_TEXT_INIT(&(data->progress.tag), 0);
+  grn_text_printf(ctx,
+                  &(data->progress.tag),
+                  "[index-column][diff][progress][%.*s]",
+                  data->index.name_size,
+                  data->index.name);
+  GRN_TEXT_PUTC(ctx, &(data->progress.tag), '\0');
+  grn_progress_logger_init(ctx,
+                           &(data->progress.logger),
+                           GRN_TEXT_VALUE(&(data->progress.tag)),
+                           "records",
+                           grn_table_size(ctx, data->source_table));
+  data->progress.logger.log_level =
     grn_index_column_diff_options_get_progress_log_level(ctx, data->options);
-  double n_records_digits = ceil(log10(data->progress.n_records + 1));
-  data->progress.n_records_digits = (int)n_records_digits;
-  grn_timeval_now(ctx, &(data->progress.start_time));
-  data->progress.previous_time = data->progress.start_time;
-}
-
-static double
-grn_index_column_diff_format_time(grn_ctx *ctx,
-                                  double seconds,
-                                  const char **unit)
-{
-  if (seconds < 60) {
-    *unit = "s";
-    return seconds;
-  } else if (seconds < (60 * 60)) {
-    *unit = "m";
-    return seconds / 60;
-  } else if (seconds < (60 * 60 * 24)) {
-    *unit = "h";
-    return seconds / 60 / 60;
-  } else {
-    *unit = "d";
-    return seconds / 60 / 60 / 24;
-  }
-}
-
-static double
-grn_index_column_diff_format_memory(grn_ctx *ctx,
-                                    uint64_t usage,
-                                    const char **unit)
-{
-  if (usage < 1024) {
-    *unit = "B";
-    return (double)usage;
-  } else if (usage < (1024 * 1024)) {
-    *unit = "KiB";
-    return (double)usage / 1024.0;
-  } else if (usage < (1024 * 1024 * 1024)) {
-    *unit = "MiB";
-    return (double)usage / 1024.0 / 1024.0;
-  } else {
-    *unit = "GiB";
-    return (double)usage / 1024.0 / 1024.0 / 1024.0;
-  }
 }
 
 static void
 grn_index_column_diff_progress(grn_ctx *ctx, grn_index_column_diff_data *data)
 {
-  data->progress.i++;
-
-  const unsigned int i = data->progress.i;
-  const unsigned int interval = data->progress.interval;
-  const unsigned int n_records = data->progress.n_records;
-  if (grn_logger_pass(ctx, data->progress.log_level) &&
-      (((i % interval) == 0) || (i == n_records))) {
-    grn_timeval current_time;
-    grn_timeval_now(ctx, &current_time);
-    const grn_timeval *start_time = &(data->progress.start_time);
-    const grn_timeval *previous_time = &(data->progress.previous_time);
-    const double elapsed_seconds =
-      ((double)(current_time.tv_sec) +
-       current_time.tv_nsec / GRN_TIME_NSEC_PER_SEC_F) -
-      ((double)(start_time->tv_sec) +
-       start_time->tv_nsec / GRN_TIME_NSEC_PER_SEC_F);
-    const double current_interval_seconds =
-      ((double)(current_time.tv_sec) +
-       current_time.tv_nsec / GRN_TIME_NSEC_PER_SEC_F) -
-      ((double)(previous_time->tv_sec) +
-       previous_time->tv_nsec / GRN_TIME_NSEC_PER_SEC_F);
-    double throughput;
-    if (grn_float_is_zero(current_interval_seconds)) {
-      throughput = interval;
-    } else {
-      throughput = interval / current_interval_seconds;
-    }
-    const double remained_seconds =
-      elapsed_seconds + ((n_records - i) / throughput);
-    const char *elapsed_unit = NULL;
-    const double elapsed_time =
-      grn_index_column_diff_format_time(ctx, elapsed_seconds, &elapsed_unit);
-    const char *remained_unit = NULL;
-    const double remained_time =
-      grn_index_column_diff_format_time(ctx, remained_seconds, &remained_unit);
-    const char *interval_unit = NULL;
-    const double interval_time =
-      grn_index_column_diff_format_time(ctx,
-                                        current_interval_seconds,
-                                        &interval_unit);
-    const char *memory_unit = NULL;
-    const double memory_usage =
-      grn_index_column_diff_format_memory(ctx,
-                                          grn_memory_get_usage(ctx),
-                                          &memory_unit);
-
-    GRN_LOG(ctx,
-            data->progress.log_level,
-            "[index-column][diff][progress][%.*s] "
-            "%*u/%u %3.0f%% %.2f%s/%.2f%s %.2f%s(%.2frecords/s) %.2f%s",
-            data->index.name_size,
-            data->index.name,
-            data->progress.n_records_digits,
-            i,
-            n_records,
-            ((double)i / (double)n_records) * 100,
-            elapsed_time,
-            elapsed_unit,
-            remained_time,
-            remained_unit,
-            interval_time,
-            interval_unit,
-            throughput,
-            memory_usage,
-            memory_unit);
-    data->progress.previous_time = current_time;
-  }
+  data->progress.logger.n_processed_targets++;
+  grn_progress_logger_log(ctx, &(data->progress.logger));
 }
 
 typedef enum {
