@@ -18,6 +18,7 @@
 #include "grn_db.h"
 #include "grn_http_client.h"
 #include "grn_language_model.hpp"
+#include "grn_progress.h"
 #include "grn_util.h"
 
 #include <groonga/smart_obj.hpp>
@@ -121,24 +122,35 @@ namespace grn {
     }
 
 #ifdef GRN_WITH_LLAMA_CPP
+    struct ModelCacheKey {
+      std::string path;
+      int32_t n_gpu_layers;
+    };
+
+    bool
+    operator<(const ModelCacheKey &a, const ModelCacheKey &b)
+    {
+      return std::tie(a.path, a.n_gpu_layers) <
+             std::tie(b.path, b.n_gpu_layers);
+    }
+
     struct ModelCache {
-    public:
       ModelCache() = default;
       ~ModelCache() = default;
 
       std::shared_ptr<LanguageModel>
-      get(const std::string &path,
+      get(const ModelCacheKey &key,
           std::function<std::shared_ptr<LanguageModel>()> load)
       {
         std::lock_guard<std::mutex> lock(mutex_);
-        auto it = models_.find(path);
+        auto it = models_.find(key);
         if (it != models_.end()) {
           return it->second;
         }
 
         auto model = load();
         if (model) {
-          models_[path] = model;
+          models_[key] = model;
         }
         return model;
       }
@@ -150,7 +162,7 @@ namespace grn {
       }
 
     private:
-      std::map<std::string, std::shared_ptr<LanguageModel>> models_;
+      std::map<ModelCacheKey, std::shared_ptr<LanguageModel>> models_;
       std::mutex mutex_;
     };
 
@@ -306,8 +318,10 @@ namespace grn {
       params.n_ctx = 0;
       params.embeddings = true;
       auto llama_ctx = llama_init_from_model(model_, params);
-      default_pooling_type_ = llama_pooling_type(llama_ctx);
-      llama_free(llama_ctx);
+      if (llama_ctx) {
+        default_pooling_type_ = llama_pooling_type(llama_ctx);
+        llama_free(llama_ctx);
+      }
     }
 
     ~Impl() { llama_model_free(model_); }
@@ -347,18 +361,19 @@ namespace grn {
     }
 
     auto model = language_model::model_cache.get(
-      model_path,
+      language_model::ModelCacheKey{model_path, n_gpu_layers},
       [this]() -> std::shared_ptr<LanguageModel> {
         auto ctx = ctx_;
         auto params = llama_model_default_params();
+        params.n_gpu_layers = n_gpu_layers;
         params.progress_callback = [](float progress, void *ctx) {
           return true;
         };
 
-        llama_model *raw_model;
         {
           language_model::CaptureError capture(ctx_);
-          raw_model = llama_model_load_from_file(model_path.c_str(), params);
+          auto raw_model =
+            llama_model_load_from_file(model_path.c_str(), params);
           if (!raw_model) {
             GRN_LM_ERROR(GRN_INVALID_ARGUMENT,
                          "[language-model-loader][load] failed to load model");
@@ -374,10 +389,10 @@ namespace grn {
             llama_model_free(raw_model);
             return nullptr;
           }
-        }
 
-        return std::make_shared<LanguageModel>(
-          new LanguageModel::Impl(raw_model));
+          return std::make_shared<LanguageModel>(
+            new LanguageModel::Impl(raw_model));
+        }
       });
     return model;
 #else
@@ -783,6 +798,9 @@ namespace grn {
           params.n_seq_max = max_n_sequences;
           params.pooling_type = pooling_type_;
           llama_ctx_ = llama_init_from_model(llama_model_, params);
+          if (!llama_ctx_) {
+            return false;
+          }
         }
 
         if (has_encoder_ && !has_decoder_) {
@@ -909,7 +927,9 @@ namespace grn {
         llama_model_(model_raw),
         default_pooling_type_(default_pooling_type),
         vectorizer_(llama_model_, default_pooling_type_),
-        input_column_value_prefix_()
+        input_column_value_prefix_(),
+        progress_callback_(nullptr),
+        progress_callback_user_data_(nullptr)
     {
     }
 
@@ -922,6 +942,13 @@ namespace grn {
       input_column_value_prefix_ = std::move(prefix);
     }
 
+    void
+    set_progress_callback(grn_progress_callback_func callback, void *user_data)
+    {
+      progress_callback_ = callback;
+      progress_callback_user_data_ = user_data;
+    }
+
     void
     vectorize(grn_ctx *ctx, std::string_view text, grn_obj *output_vector)
     {
@@ -945,14 +972,32 @@ namespace grn {
 #ifdef GRN_WITH_LLAMA_CPP
       language_model::CaptureError capture(ctx);
 
+      grn_progress progress;
+      progress.type = GRN_PROGRESS_LANGUAGE_MODEL_INFERENCER;
+
       auto task_executor = grn_ctx_get_task_executor(ctx);
       if (!task_executor->is_parallel()) {
-        vectorizer_.vectorize_in_batch(ctx,
-                                       cursor,
-                                       input_column,
-                                       input_column_value_prefix_,
-                                       output,
-                                       tag);
+        if (progress_callback_) {
+          progress.value.language_model_inferencer.n_processed_records = 1;
+          auto output_with_progress =
+            [&](grn_ctx *ctx, grn_id id, grn_obj *embedding) {
+              output(ctx, id, embedding);
+              progress_callback_(ctx, &progress, progress_callback_user_data_);
+            };
+          vectorizer_.vectorize_in_batch(ctx,
+                                         cursor,
+                                         input_column,
+                                         input_column_value_prefix_,
+                                         output_with_progress,
+                                         tag);
+        } else {
+          vectorizer_.vectorize_in_batch(ctx,
+                                         cursor,
+                                         input_column,
+                                         input_column_value_prefix_,
+                                         output,
+                                         tag);
+        }
         return;
       }
 
@@ -1070,6 +1115,11 @@ namespace grn {
           auto embedding = &(processed_task->embeddings[i]);
           output(ctx, id, embedding);
         }
+        if (progress_callback_) {
+          progress.value.language_model_inferencer.n_processed_records =
+            processed_task->ids.size();
+          progress_callback_(ctx, &progress, progress_callback_user_data_);
+        }
       }
       task_executor->wait_all();
 #else
@@ -1085,6 +1135,8 @@ namespace grn {
     Vectorizer vectorizer_;
 #endif
     std::string input_column_value_prefix_;
+    grn_progress_callback_func progress_callback_;
+    void *progress_callback_user_data_;
   };
 
   LanguageModelInferencer::LanguageModelInferencer(Impl *impl)
@@ -1100,6 +1152,13 @@ namespace grn {
     impl_->set_input_column_value_prefix(std::move(prefix));
   }
 
+  void
+  LanguageModelInferencer::set_progress_callback(
+    grn_progress_callback_func callback, void *user_data)
+  {
+    impl_->set_progress_callback(callback, user_data);
+  }
+
   void
   LanguageModelInferencer::vectorize(grn_ctx *ctx,
                                      std::string_view text,
@@ -1529,6 +1588,25 @@ grn_language_model_loader_set_model(grn_ctx *ctx,
   GRN_API_RETURN(ctx->rc);
 }
 
+grn_rc
+grn_language_model_loader_set_n_gpu_layers(grn_ctx *ctx,
+                                           grn_language_model_loader *loader,
+                                           int32_t n_gpu_layers)
+{
+  const char *tag = "[language-model-loader][set-n-gpu-layers]";
+  GRN_API_ENTER;
+  if (!loader) {
+    ERR(GRN_INVALID_ARGUMENT, "%s loader must not be NULL", tag);
+    GRN_API_RETURN(ctx->rc);
+  }
+#ifdef GRN_WITH_LLAMA_CPP
+  loader->loader.n_gpu_layers = n_gpu_layers;
+#else
+  ERR(GRN_FUNCTION_NOT_IMPLEMENTED, "%s llama.cpp isn't enabled", tag);
+#endif
+  GRN_API_RETURN(ctx->rc);
+}
+
 grn_language_model *
 grn_language_model_loader_load(grn_ctx *ctx, grn_language_model_loader *loader)
 {
@@ -1614,6 +1692,24 @@ grn_language_model_inferencer_set_input_column_value_prefix(
   GRN_API_RETURN(ctx->rc);
 }
 
+grn_rc
+grn_language_model_inferencer_set_progress_callback(
+  grn_ctx *ctx,
+  grn_language_model_inferencer *inferencer,
+  grn_progress_callback_func callback,
+  void *user_data)
+{
+  GRN_API_ENTER;
+  if (!inferencer) {
+    ERR(GRN_INVALID_ARGUMENT,
+        "[language-model-inferencer][progress-callback][set] "
+        "inferencer must not be NULL");
+    GRN_API_RETURN(ctx->rc);
+  }
+  inferencer->inferencer->set_progress_callback(callback, user_data);
+  GRN_API_RETURN(ctx->rc);
+}
+
 grn_rc
 grn_language_model_inferencer_vectorize(
   grn_ctx *ctx,
