@@ -23,6 +23,9 @@ module Groonga
       if data.max_element_intervals
         self.max_element_intervals = data.max_element_intervals
       end
+      if data.min_interval
+        self.min_interval = data.min_interval
+      end
       if data.similarity_threshold
         self.similarity_threshold = data.similarity_threshold
       end
@@ -35,14 +38,12 @@ module Groonga
       data.search_indexes.each do |search_index|
         put_index(search_index.index_column,
                   search_index.section_id,
+                  search_index.start_position,
                   search_index.weight,
                   search_index.scorer,
                   search_index.scorer_args_expr,
                   search_index.scorer_args_expr_offset || 0)
       end
-      if data.start_position
-        self.start_position = data.start_position
-      end
     end
   end
 end
