@@ -4,7 +4,8 @@
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
-  License version 2.1 as published by the Free Software Foundation.
+  License as published by the Free Software Foundation; either
+  version 2.1 of the License, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -201,10 +202,21 @@ static const char *operator_script_syntaxes[] = {
 
 #define GRN_OP_LAST GRN_OP_ORDERED_NEAR_PHRASE_PRODUCT
 
+static inline bool
+grn_operator_is_valid(grn_operator op)
+{
+  /* We can't assume grn_operator is signed or unsigned. If
+   * grn_operator is unsigned, "op >= 0" may cause a warning. But "op
+   * >= 0" is needed when grn_operator is signed. We can suppress the
+   * warning with unsigned by "(int)op >= 0" and keep the check for
+   * signed. */
+  return (int)op >= 0 && op <= GRN_OP_LAST;
+}
+
 const char *
 grn_operator_to_string(grn_operator op)
 {
-  if (op >= 0 && op <= GRN_OP_LAST) {
+  if (grn_operator_is_valid(op)) {
     return operator_names[op];
   } else {
     return "unknown";
@@ -214,7 +226,7 @@ grn_operator_to_string(grn_operator op)
 const char *
 grn_operator_to_script_syntax(grn_operator op)
 {
-  if (op >= 0 && op <= GRN_OP_LAST) {
+  if (grn_operator_is_valid(op)) {
     return operator_script_syntaxes[op];
   } else {
     return "unknown";
@@ -307,7 +319,7 @@ grn_operator_to_exec_func(grn_operator op)
       }                                                                        \
       break;                                                                   \
     default:                                                                   \
-      r = GRN_FALSE;                                                           \
+      r = false;                                                               \
       break;                                                                   \
     }                                                                          \
   } while (0)
@@ -358,7 +370,7 @@ grn_operator_to_exec_func(grn_operator op)
       }                                                                        \
       break;                                                                   \
     default:                                                                   \
-      r = GRN_FALSE;                                                           \
+      r = false;                                                               \
       break;                                                                   \
     }                                                                          \
   } while (0)
@@ -367,7 +379,7 @@ grn_operator_to_exec_func(grn_operator op)
   do {                                                                         \
     switch (x->header.domain) {                                                \
     case GRN_DB_VOID:                                                          \
-      r = GRN_FALSE;                                                           \
+      r = false;                                                               \
       break;                                                                   \
     case GRN_DB_INT8:                                                          \
       {                                                                        \
@@ -440,17 +452,16 @@ grn_operator_to_exec_func(grn_operator op)
           {                                                                    \
             grn_obj time_value_;                                               \
             GRN_TIME_INIT(&time_value_, 0);                                    \
-            if (grn_obj_cast(ctx, y, &time_value_, GRN_FALSE) ==               \
-                GRN_SUCCESS) {                                                 \
+            if (grn_obj_cast(ctx, y, &time_value_, false) == GRN_SUCCESS) {    \
               r = (x_ == GRN_TIME_VALUE(&time_value_));                        \
             } else {                                                           \
-              r = GRN_FALSE;                                                   \
+              r = false;                                                       \
             }                                                                  \
             GRN_OBJ_FIN(ctx, &time_value_);                                    \
           }                                                                    \
           break;                                                               \
         default:                                                               \
-          r = GRN_FALSE;                                                       \
+          r = false;                                                           \
           break;                                                               \
         }                                                                      \
       }                                                                        \
@@ -494,7 +505,7 @@ grn_operator_to_exec_func(grn_operator op)
           }                                                                    \
           break;                                                               \
         default:                                                               \
-          r = GRN_FALSE;                                                       \
+          r = false;                                                           \
           break;                                                               \
         }                                                                      \
       }                                                                        \
@@ -532,7 +543,7 @@ grn_operator_to_exec_func(grn_operator op)
           }                                                                    \
           break;                                                               \
         default:                                                               \
-          r = GRN_FALSE;                                                       \
+          r = false;                                                           \
           break;                                                               \
         }                                                                      \
       }                                                                        \
@@ -559,23 +570,23 @@ grn_operator_to_exec_func(grn_operator op)
         grn_obj dest;                                                          \
         if (x->header.domain < y->header.domain) {                             \
           GRN_OBJ_INIT(&dest, GRN_BULK, 0, y->header.domain);                  \
-          if (!grn_obj_cast(ctx, x, &dest, GRN_FALSE)) {                       \
+          if (!grn_obj_cast(ctx, x, &dest, false)) {                           \
             r = (GRN_BULK_VSIZE(&dest) == GRN_BULK_VSIZE(y) &&                 \
                  !memcmp(GRN_BULK_HEAD(&dest),                                 \
                          GRN_BULK_HEAD(y),                                     \
                          GRN_BULK_VSIZE(y)));                                  \
           } else {                                                             \
-            r = GRN_FALSE;                                                     \
+            r = false;                                                         \
           }                                                                    \
         } else {                                                               \
           GRN_OBJ_INIT(&dest, GRN_BULK, 0, x->header.domain);                  \
-          if (!grn_obj_cast(ctx, y, &dest, GRN_FALSE)) {                       \
+          if (!grn_obj_cast(ctx, y, &dest, false)) {                           \
             r = (GRN_BULK_VSIZE(&dest) == GRN_BULK_VSIZE(x) &&                 \
                  !memcmp(GRN_BULK_HEAD(&dest),                                 \
                          GRN_BULK_HEAD(x),                                     \
                          GRN_BULK_VSIZE(x)));                                  \
           } else {                                                             \
-            r = GRN_FALSE;                                                     \
+            r = false;                                                         \
           }                                                                    \
         }                                                                      \
         GRN_OBJ_FIN(ctx, &dest);                                               \
@@ -584,29 +595,29 @@ grn_operator_to_exec_func(grn_operator op)
     }                                                                          \
   } while (0)
 
-static grn_bool
+static bool
 exec_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
 {
   switch (x->header.type) {
   case GRN_BULK:
     if (y->header.type == GRN_BULK) {
-      grn_bool is_equal = GRN_FALSE;
+      bool is_equal = false;
       DO_EQ(x, y, is_equal);
       return is_equal;
     } else {
-      return GRN_FALSE;
+      return false;
     }
     break;
   case GRN_VECTOR:
     if (y->header.type == GRN_VECTOR) {
-      grn_bool is_equal = GRN_TRUE;
+      bool is_equal = true;
       unsigned int x_size = grn_vector_size(ctx, x);
       unsigned int y_size = grn_vector_size(ctx, y);
       unsigned int i;
       grn_obj x_element;
       grn_obj y_element;
       if (x_size != y_size) {
-        return GRN_FALSE;
+        return false;
       }
       GRN_VOID_INIT(&x_element);
       GRN_VOID_INIT(&y_element);
@@ -625,7 +636,7 @@ exec_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
         y_size =
           grn_vector_get_element(ctx, y, i, &y_value, &y_weight, &y_domain);
         if (x_weight != y_weight) {
-          is_equal = GRN_FALSE;
+          is_equal = false;
           break;
         }
         grn_obj_reinit(ctx, &x_element, x_domain, 0);
@@ -641,12 +652,12 @@ exec_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
       GRN_OBJ_FIN(ctx, &y_element);
       return is_equal;
     } else {
-      return GRN_FALSE;
+      return false;
     }
     break;
   case GRN_UVECTOR:
     if (y->header.type == GRN_UVECTOR) {
-      grn_bool is_equal = GRN_TRUE;
+      bool is_equal = true;
       unsigned int x_size = grn_vector_size(ctx, x);
       unsigned int y_size = grn_vector_size(ctx, y);
       unsigned int i;
@@ -655,7 +666,7 @@ exec_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
       unsigned int x_element_size = grn_uvector_element_size(ctx, x);
       unsigned int y_element_size = grn_uvector_element_size(ctx, y);
       if (x_size != y_size) {
-        return GRN_FALSE;
+        return false;
       }
       GRN_OBJ_INIT(&x_element,
                    GRN_BULK,
@@ -682,7 +693,7 @@ exec_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
       GRN_OBJ_FIN(ctx, &y_element);
       return is_equal;
     } else if (y->header.type == GRN_VECTOR) {
-      grn_bool is_equal = GRN_TRUE;
+      bool is_equal = true;
       unsigned int x_size = grn_vector_size(ctx, x);
       unsigned int y_size = grn_vector_size(ctx, y);
       unsigned int i;
@@ -690,7 +701,7 @@ exec_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
       grn_obj y_element;
       unsigned int x_element_size = grn_uvector_element_size(ctx, x);
       if (x_size != y_size) {
-        return GRN_FALSE;
+        return false;
       }
       GRN_OBJ_INIT(&x_element,
                    GRN_BULK,
@@ -723,27 +734,27 @@ exec_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
       GRN_OBJ_FIN(ctx, &y_element);
       return is_equal;
     } else {
-      return GRN_FALSE;
+      return false;
     }
     break;
   default:
-    return GRN_FALSE;
+    return false;
   }
 }
 
-grn_bool
+bool
 grn_operator_exec_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
 {
-  grn_bool r = GRN_FALSE;
+  bool r = false;
   GRN_API_ENTER;
   r = exec_equal(ctx, x, y);
   GRN_API_RETURN(r);
 }
 
-grn_bool
+bool
 grn_operator_exec_not_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
 {
-  grn_bool r = GRN_FALSE;
+  bool r = false;
   GRN_API_ENTER;
   r = exec_equal(ctx, x, y);
   GRN_API_RETURN(!r);
@@ -789,7 +800,7 @@ grn_operator_exec_not_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
       r = (x_ op GRN_FLOAT_VALUE(y));                                          \
       break;                                                                   \
     default:                                                                   \
-      r = GRN_FALSE;                                                           \
+      r = false;                                                               \
       break;                                                                   \
     }                                                                          \
   } while (0)
@@ -834,7 +845,7 @@ grn_operator_exec_not_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
       r = (x_ op GRN_FLOAT_VALUE(y));                                          \
       break;                                                                   \
     default:                                                                   \
-      r = GRN_FALSE;                                                           \
+      r = false;                                                               \
       break;                                                                   \
     }                                                                          \
   } while (0)
@@ -848,8 +859,8 @@ grn_operator_exec_not_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
       {                                                                        \
         grn_obj y_;                                                            \
         GRN_OBJ_INIT(&y_, GRN_BULK, 0, x->header.domain);                      \
-        if (grn_obj_cast(ctx, y, &y_, GRN_FALSE)) {                            \
-          r = GRN_FALSE;                                                       \
+        if (grn_obj_cast(ctx, y, &y_, false)) {                                \
+          r = false;                                                           \
         } else {                                                               \
           DO_COMPARE_SCALAR_SUB_NUMERIC_SIGNED(&y_, op);                       \
         }                                                                      \
@@ -871,8 +882,8 @@ grn_operator_exec_not_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
       {                                                                        \
         grn_obj y_;                                                            \
         GRN_OBJ_INIT(&y_, GRN_BULK, 0, x->header.domain);                      \
-        if (grn_obj_cast(ctx, y, &y_, GRN_FALSE)) {                            \
-          r = GRN_FALSE;                                                       \
+        if (grn_obj_cast(ctx, y, &y_, false)) {                                \
+          r = false;                                                           \
         } else {                                                               \
           DO_COMPARE_SCALAR_SUB_NUMERIC_UNSIGNED(&y_, op);                     \
         }                                                                      \
@@ -906,13 +917,13 @@ grn_operator_exec_not_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
             DO_COMPARE_SCALAR_SUB_BUILTIN_SIGNED(op);                          \
             y = y_original;                                                    \
           } else {                                                             \
-            r = GRN_FALSE;                                                     \
+            r = false;                                                         \
           }                                                                    \
           GRN_OBJ_FIN(ctx, &y_key);                                            \
         }                                                                      \
         break;                                                                 \
       default:                                                                 \
-        r = GRN_FALSE;                                                         \
+        r = false;                                                             \
         break;                                                                 \
       }                                                                        \
       grn_obj_unlink(ctx, y_table);                                            \
@@ -942,13 +953,13 @@ grn_operator_exec_not_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
             DO_COMPARE_SCALAR_SUB_BUILTIN_UNSIGNED(op);                        \
             y = y_original;                                                    \
           } else {                                                             \
-            r = GRN_FALSE;                                                     \
+            r = false;                                                         \
           }                                                                    \
           GRN_OBJ_FIN(ctx, &y_key);                                            \
         }                                                                      \
         break;                                                                 \
       default:                                                                 \
-        r = GRN_FALSE;                                                         \
+        r = false;                                                             \
         break;                                                                 \
       }                                                                        \
       grn_obj_unlink(ctx, y_table);                                            \
@@ -1031,17 +1042,16 @@ grn_operator_exec_not_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
           {                                                                    \
             grn_obj time_value_;                                               \
             GRN_TIME_INIT(&time_value_, 0);                                    \
-            if (grn_obj_cast(ctx, y, &time_value_, GRN_FALSE) ==               \
-                GRN_SUCCESS) {                                                 \
+            if (grn_obj_cast(ctx, y, &time_value_, false) == GRN_SUCCESS) {    \
               r = (x_ op GRN_TIME_VALUE(&time_value_));                        \
             } else {                                                           \
-              r = GRN_FALSE;                                                   \
+              r = false;                                                       \
             }                                                                  \
             GRN_OBJ_FIN(ctx, &time_value_);                                    \
           }                                                                    \
           break;                                                               \
         default:                                                               \
-          r = GRN_FALSE;                                                       \
+          r = false;                                                           \
           break;                                                               \
         }                                                                      \
       }                                                                        \
@@ -1094,7 +1104,7 @@ grn_operator_exec_not_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
       }                                                                        \
       break;                                                                   \
     default:                                                                   \
-      r = GRN_FALSE;                                                           \
+      r = false;                                                               \
       break;                                                                   \
     }                                                                          \
   } while (0)
@@ -1120,13 +1130,13 @@ grn_operator_exec_not_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
             DO_COMPARE_SCALAR_BUILTIN((&x_key), y, r, op);                     \
             x = x_original;                                                    \
           } else {                                                             \
-            r = GRN_FALSE;                                                     \
+            r = false;                                                         \
           }                                                                    \
           GRN_OBJ_FIN(ctx, &x_key);                                            \
         }                                                                      \
         break;                                                                 \
       default:                                                                 \
-        r = GRN_FALSE;                                                         \
+        r = false;                                                             \
         break;                                                                 \
       }                                                                        \
       grn_obj_unlink(ctx, x_table);                                            \
@@ -1159,53 +1169,53 @@ grn_operator_exec_not_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
       GRN_OBJ_FIN(ctx, &element_buffer);                                       \
     } else {                                                                   \
       if (GRN_BULK_VSIZE(x) == 0 || GRN_BULK_VSIZE(y) == 0) {                  \
-        r = GRN_FALSE;                                                         \
+        r = false;                                                             \
       } else {                                                                 \
         DO_COMPARE_SCALAR(x, y, r, op);                                        \
       }                                                                        \
     }                                                                          \
   } while (0)
 
-grn_bool
+bool
 grn_operator_exec_less(grn_ctx *ctx, grn_obj *x, grn_obj *y)
 {
-  grn_bool r = GRN_FALSE;
+  bool r = false;
   GRN_API_ENTER;
   DO_COMPARE(x, y, r, <);
   GRN_API_RETURN(r);
 }
 
-grn_bool
+bool
 grn_operator_exec_greater(grn_ctx *ctx, grn_obj *x, grn_obj *y)
 {
-  grn_bool r = GRN_FALSE;
+  bool r = false;
   GRN_API_ENTER;
   DO_COMPARE(x, y, r, >);
   GRN_API_RETURN(r);
 }
 
-grn_bool
+bool
 grn_operator_exec_less_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
 {
-  grn_bool r = GRN_FALSE;
+  bool r = false;
   GRN_API_ENTER;
   DO_COMPARE(x, y, r, <=);
   GRN_API_RETURN(r);
 }
 
-grn_bool
+bool
 grn_operator_exec_greater_equal(grn_ctx *ctx, grn_obj *x, grn_obj *y)
 {
-  grn_bool r = GRN_FALSE;
+  bool r = false;
   GRN_API_ENTER;
   DO_COMPARE(x, y, r, >=);
   GRN_API_RETURN(r);
 }
 
-static grn_bool
+static bool
 exec_match_uvector_bulk(grn_ctx *ctx, grn_obj *uvector, grn_obj *query)
 {
-  grn_bool matched = GRN_FALSE;
+  bool matched = false;
   unsigned int i, size;
   grn_obj element;
   unsigned int element_size;
@@ -1220,7 +1230,7 @@ exec_match_uvector_bulk(grn_ctx *ctx, grn_obj *uvector, grn_obj *query)
                    GRN_BULK_HEAD(uvector) + (element_size * i),
                    element_size);
     if (grn_operator_exec_equal(ctx, &element, query)) {
-      matched = GRN_TRUE;
+      matched = true;
       break;
     }
   }
@@ -1229,10 +1239,10 @@ exec_match_uvector_bulk(grn_ctx *ctx, grn_obj *uvector, grn_obj *query)
   return matched;
 }
 
-static grn_bool
+static bool
 exec_match_vector_bulk(grn_ctx *ctx, grn_obj *vector, grn_obj *query)
 {
-  grn_bool matched = GRN_FALSE;
+  bool matched = false;
   unsigned int i, size;
   grn_obj element;
 
@@ -1248,7 +1258,7 @@ exec_match_vector_bulk(grn_ctx *ctx, grn_obj *vector, grn_obj *query)
     grn_obj_reinit(ctx, &element, domain_id, 0);
     grn_bulk_write(ctx, &element, content, content_size);
     if (grn_operator_exec_equal(ctx, &element, query)) {
-      matched = GRN_TRUE;
+      matched = true;
       break;
     }
   }
@@ -1284,7 +1294,7 @@ exec_prefix_vector_bulk(grn_ctx *ctx, grn_obj *vector, grn_obj *query)
 }
 
 #ifdef GRN_SUPPORT_REGEXP
-static grn_bool
+static bool
 regexp_is_match(grn_ctx *ctx,
                 OnigRegex regex,
                 const char *target,
@@ -1303,7 +1313,7 @@ regexp_is_match(grn_ctx *ctx,
 }
 #endif /* GRN_SUPPORT_REGEXP */
 
-static grn_bool
+static bool
 string_have_sub_text(grn_ctx *ctx,
                      const char *text,
                      unsigned int text_len,
@@ -1319,7 +1329,7 @@ string_have_sub_text(grn_ctx *ctx,
   return grn_raw_string_have_sub_string(ctx, &string, &sub_string);
 }
 
-static grn_bool
+static bool
 string_have_prefix(grn_ctx *ctx,
                    const char *target,
                    unsigned int target_len,
@@ -1329,7 +1339,7 @@ string_have_prefix(grn_ctx *ctx,
   return (target_len >= prefix_len && strncmp(target, prefix, prefix_len) == 0);
 }
 
-static grn_bool
+static bool
 string_match_regexp(grn_ctx *ctx,
                     const char *target,
                     unsigned int target_len,
@@ -1338,7 +1348,6 @@ string_match_regexp(grn_ctx *ctx,
 {
 #ifdef GRN_SUPPORT_REGEXP
   OnigRegex regex;
-  grn_bool matched;
 
   regex = grn_onigmo_new(ctx,
                          pattern,
@@ -1347,18 +1356,18 @@ string_match_regexp(grn_ctx *ctx,
                          GRN_ONIGMO_SYNTAX_DEFAULT,
                          "[operator]");
   if (!regex) {
-    return GRN_FALSE;
+    return false;
   }
 
-  matched = regexp_is_match(ctx, regex, target, target_len);
+  bool matched = regexp_is_match(ctx, regex, target, target_len);
   onig_free(regex);
   return matched;
 #else  /* GRN_SUPPORT_REGEXP */
-  return GRN_FALSE;
+  return false;
 #endif /* GRN_SUPPORT_REGEXP */
 }
 
-static grn_bool
+static bool
 exec_text_operator(grn_ctx *ctx,
                    grn_operator op,
                    const char *target,
@@ -1366,10 +1375,10 @@ exec_text_operator(grn_ctx *ctx,
                    const char *query,
                    unsigned int query_len)
 {
-  grn_bool matched = GRN_FALSE;
+  bool matched = false;
 
   if (target_len == 0 || query_len == 0) {
-    return GRN_FALSE;
+    return false;
   }
 
   switch (op) {
@@ -1383,14 +1392,14 @@ exec_text_operator(grn_ctx *ctx,
     matched = string_match_regexp(ctx, target, target_len, query, query_len);
     break;
   default:
-    matched = GRN_FALSE;
+    matched = false;
     break;
   }
 
   return matched;
 }
 
-static grn_bool
+static bool
 exec_text_operator_raw_text_raw_text(grn_ctx *ctx,
                                      grn_operator op,
                                      const char *target,
@@ -1405,10 +1414,10 @@ exec_text_operator_raw_text_raw_text(grn_ctx *ctx,
   const char *norm_query_raw;
   unsigned int norm_target_raw_length_in_bytes;
   unsigned int norm_query_raw_length_in_bytes;
-  grn_bool matched = GRN_FALSE;
+  bool matched = false;
 
   if (target_len == 0 || query_len == 0) {
-    return GRN_FALSE;
+    return false;
   }
 
   normalizer = grn_ctx_get(ctx, GRN_NORMALIZER_AUTO_NAME, -1);
@@ -1448,7 +1457,7 @@ exec_text_operator_raw_text_raw_text(grn_ctx *ctx,
   return matched;
 }
 
-static grn_bool
+static bool
 exec_text_operator_record_text(grn_ctx *ctx,
                                grn_operator op,
                                grn_obj *record,
@@ -1458,14 +1467,14 @@ exec_text_operator_record_text(grn_ctx *ctx,
   grn_obj *normalizer;
   char record_key[GRN_TABLE_MAX_KEY_SIZE];
   int record_key_len;
-  grn_bool matched = GRN_FALSE;
+  bool matched = false;
 
   if (table->header.domain != GRN_DB_SHORT_TEXT) {
-    return GRN_FALSE;
+    return false;
   }
 
   if (GRN_TEXT_LEN(query) == 0) {
-    return GRN_FALSE;
+    return false;
   }
 
   record_key_len = grn_table_get_key(ctx,
@@ -1516,7 +1525,7 @@ exec_text_operator_record_text(grn_ctx *ctx,
   return matched;
 }
 
-static grn_bool
+static bool
 exec_text_operator_text_text(grn_ctx *ctx,
                              grn_operator op,
                              grn_obj *target,
@@ -1530,7 +1539,7 @@ exec_text_operator_text_text(grn_ctx *ctx,
                                               GRN_TEXT_LEN(query));
 }
 
-static grn_bool
+static bool
 exec_text_operator_bulk_bulk(grn_ctx *ctx,
                              grn_operator op,
                              grn_obj *target,
@@ -1548,7 +1557,7 @@ exec_text_operator_bulk_bulk(grn_ctx *ctx,
     default:
       break;
     }
-    return GRN_FALSE;
+    return false;
   default:
     {
       grn_obj *domain;
@@ -1564,14 +1573,14 @@ exec_text_operator_bulk_bulk(grn_ctx *ctx,
         }
       }
     }
-    return GRN_FALSE;
+    return false;
   }
 }
 
-grn_bool
+bool
 grn_operator_exec_match(grn_ctx *ctx, grn_obj *target, grn_obj *sub_text)
 {
-  grn_bool matched;
+  bool matched;
   GRN_API_ENTER;
   switch (target->header.type) {
   case GRN_UVECTOR:
@@ -1611,11 +1620,11 @@ grn_operator_exec_prefix(grn_ctx *ctx, grn_obj *target, grn_obj *prefix)
   GRN_API_RETURN(matched);
 }
 
-static grn_bool
+static bool
 exec_regexp_uvector_bulk(grn_ctx *ctx, grn_obj *uvector, grn_obj *pattern)
 {
 #ifdef GRN_SUPPORT_REGEXP
-  grn_bool matched = GRN_FALSE;
+  bool matched = false;
   unsigned int i, size;
   OnigRegex regex;
   grn_obj *domain;
@@ -1624,7 +1633,7 @@ exec_regexp_uvector_bulk(grn_ctx *ctx, grn_obj *uvector, grn_obj *pattern)
 
   size = grn_uvector_size(ctx, uvector);
   if (size == 0) {
-    return GRN_FALSE;
+    return false;
   }
 
   regex = grn_onigmo_new(ctx,
@@ -1634,13 +1643,13 @@ exec_regexp_uvector_bulk(grn_ctx *ctx, grn_obj *uvector, grn_obj *pattern)
                          GRN_ONIGMO_SYNTAX_DEFAULT,
                          "[operator]");
   if (!regex) {
-    return GRN_FALSE;
+    return false;
   }
 
   domain = grn_ctx_at(ctx, uvector->header.domain);
   if (!domain) {
     onig_free(regex);
-    return GRN_FALSE;
+    return false;
   }
 
   grn_table_get_info(ctx, domain, NULL, NULL, NULL, &normalizer, NULL);
@@ -1693,22 +1702,22 @@ exec_regexp_uvector_bulk(grn_ctx *ctx, grn_obj *uvector, grn_obj *pattern)
 
   return matched;
 #else  /* GRN_SUPPORT_REGEXP */
-  return GRN_FALSE;
+  return false;
 #endif /* GRN_SUPPORT_REGEXP */
 }
 
-static grn_bool
+static bool
 exec_regexp_vector_bulk(grn_ctx *ctx, grn_obj *vector, grn_obj *pattern)
 {
 #ifdef GRN_SUPPORT_REGEXP
   grn_obj *normalizer = NULL;
-  grn_bool matched = GRN_FALSE;
+  bool matched = false;
   unsigned int i, size;
   OnigRegex regex;
 
   size = grn_vector_size(ctx, vector);
   if (size == 0) {
-    return GRN_FALSE;
+    return false;
   }
 
   regex = grn_onigmo_new(ctx,
@@ -1718,7 +1727,7 @@ exec_regexp_vector_bulk(grn_ctx *ctx, grn_obj *vector, grn_obj *pattern)
                          GRN_ONIGMO_SYNTAX_DEFAULT,
                          "[operator]");
   if (!regex) {
-    return GRN_FALSE;
+    return false;
   }
 
   normalizer = grn_ctx_get(ctx, GRN_NORMALIZER_AUTO_NAME, -1);
@@ -1760,14 +1769,14 @@ exec_regexp_vector_bulk(grn_ctx *ctx, grn_obj *vector, grn_obj *pattern)
 
   return matched;
 #else  /* GRN_SUPPORT_REGEXP */
-  return GRN_FALSE;
+  return false;
 #endif /* GRN_SUPPORT_REGEXP */
 }
 
-grn_bool
+bool
 grn_operator_exec_regexp(grn_ctx *ctx, grn_obj *target, grn_obj *pattern)
 {
-  grn_bool matched = GRN_FALSE;
+  bool matched = false;
   GRN_API_ENTER;
   switch (target->header.type) {
   case GRN_UVECTOR:
@@ -1780,7 +1789,7 @@ grn_operator_exec_regexp(grn_ctx *ctx, grn_obj *target, grn_obj *pattern)
     matched = exec_text_operator_bulk_bulk(ctx, GRN_OP_REGEXP, target, pattern);
     break;
   default:
-    matched = GRN_FALSE;
+    matched = false;
     break;
   }
   GRN_API_RETURN(matched);
