@@ -3,7 +3,8 @@
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
-  License version 2.1 as published by the Free Software Foundation.
+  License as published by the Free Software Foundation; either
+  version 2.1 of the License, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -405,7 +406,7 @@ grn_selector_data_current_set_default_tag_raw_no_validation(grn_ctx *ctx,
   return rc;
 }
 
-static grn_inline void
+static inline void
 grn_selector_data_add_score(grn_ctx *ctx,
                             grn_selector_data *data,
                             grn_obj *result_set,
@@ -440,7 +441,7 @@ grn_selector_data_add_score(grn_ctx *ctx,
                     GRN_OBJ_INCR);
 }
 
-static grn_inline void
+static inline void
 grn_selector_data_append_tags(grn_ctx *ctx,
                               grn_selector_data *data,
                               grn_obj *result_set,
