@@ -4,7 +4,8 @@
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
-  License version 2.1 as published by the Free Software Foundation.
+  License as published by the Free Software Foundation; either
+  version 2.1 of the License, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,7 +37,7 @@ grn_char_type_to_string(grn_char_type type)
     } else {                                            \
       string = type_string;                             \
     }                                                   \
-  } while (GRN_FALSE)
+  } while (false)
 
   switch (GRN_CHAR_TYPE(type)) {
   case GRN_CHAR_NULL :
