@@ -4,7 +4,8 @@
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
-  License version 2.1 as published by the Free Software Foundation.
+  License as published by the Free Software Foundation; either
+  version 2.1 of the License, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -390,6 +391,8 @@ grn_table_cache_module_options(grn_ctx *ctx,
                                                   options,
                                                   revision,
                                                   data->close_options_func);
+      } else if (options) {
+        data->close_options_func(ctx, options);
       }
     }
   }
