@@ -4,7 +4,8 @@
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
-  License version 2.1 as published by the Free Software Foundation.
+  License as published by the Free Software Foundation; either
+  version 2.1 of the License, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -71,7 +72,7 @@ namespace grn {
     if (length > 0) {
       switch (domain) {
       case GRN_DB_BOOL:
-        value = *reinterpret_cast<const grn_bool *>(raw_value);
+        value = *reinterpret_cast<const bool *>(raw_value);
         break;
       case GRN_DB_INT8:
         value =
